==> lib_common_fx-0.0.13.tar.gz: lib/ui/fx_radio_button.dart <==
import 'package:flutter/cupertino.dart';
import 'package:lib_common_fx/lib_common_fx.dart';

import '../utils/image_utils.dart';

class FxRadioButton<T> extends StatelessWidget {
  const FxRadioButton({
    Key? key,
    required this.value,
    required this.groupValue,
    required this.onChanged,
    this.text,
    this.size = 16.0,
    this.toggleable = false,
    this.activeImg = "images/ic_trans_price_change_select.png" ,
    this.fillImg = "images/ic_trans_price_change_unselect.png",
  })  : assert(toggleable != null),
        assert(activeImg != null, "Picture cannot be empty"),
        assert(fillImg != null, "Picture cannot be empty"),
        super(key: key);

  final T value;
  final T? groupValue;
  final ValueChanged<T?> onChanged;

  final String? text;
  final double size;

  ///是否允许回到未选中状态
  final bool toggleable;

  ///选中状态图片
  final String activeImg;

  ///未选中状态图片
  final String fillImg;

  bool get _selected => value == groupValue;

  T? get _value => toggleable && _selected ? null : value;

  @override
  Widget build(BuildContext context) {
    List<Widget> children = <Widget>[];
    children.add(ImageUtil.assetImage(_selected ? activeImg : fillImg , height: size, width: size));
    if (text != null) {
      children.add(const SizedBox(width: 8));
      children.add(CenterText(text!, style: CenterText.content.apply(color: FXColor.main_black1)));
    }
    return GestureDetector(
      child: Container(
        // constraints: const BoxConstraints(minWidth: 112),
          padding: const EdgeInsets.only(top: 10, bottom: 10, left: 16),
          child: Row(
              mainAxisAlignment: MainAxisAlignment.end,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: children)),
      onTap: onClick,
    );
  }

  void onClick() {
    onChanged(_value);
  }
}

==> lib_common_fx-0.0.41.tar.gz: lib/ui/fx_radio_button.dart <==
import 'package:flutter/cupertino.dart';
import 'package:lib_common_fx/lib_common_fx.dart';

import '../utils/image_utils.dart';

class FxRadioButton<T> extends StatelessWidget {
  const FxRadioButton({
    Key? key,
    required this.value,
    required this.groupValue,
    required this.onChanged,
    this.text,
    this.size = 16.0,
    this.toggleable = false,
    this.activeImg = "images/ic_trans_price_change_select.png",
    this.fillImg = "images/ic_trans_price_change_unselect.png",
  }) : super(key: key);

  final T value;
  final T? groupValue;
  final ValueChanged<T?> onChanged;

  final String? text;
  final double size;

  ///是否允许回到未选中状态
  final bool toggleable;

  ///选中状态图片
  final String activeImg;

  ///未选中状态图片
  final String fillImg;

  bool get _selected => value == groupValue;

  T? get _value => toggleable && _selected ? null : value;

  @override
  Widget build(BuildContext context) {
    List<Widget> children = <Widget>[];
    children.add(ImageUtil.assetImage(_selected ? activeImg : fillImg,
        height: size, width: size));
    if (text != null) {
      children.add(const SizedBox(width: 8));
      children.add(CenterText(text!,
          style: CenterText.content.apply(color: FXColor.main_black1)));
    }
    return GestureDetector(
      child: Container(
          // constraints: const BoxConstraints(minWidth: 112),
          padding: const EdgeInsets.only(top: 10, bottom: 10, left: 16),
          child: Row(
              mainAxisAlignment: MainAxisAlignment.end,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: children)),
      onTap: onClick,
    );
  }

  void onClick() {
    onChanged(_value);
  }
}
